# Copyright 2018-2019 Fairphone B.V.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

TARGET_ARCH := arm
TARGET_ARCH_VARIANT := armv7-a-neon
TARGET_BOARD_PLATFORM := msm8974
TARGET_BOARD_PLATFORM_GPU := qcom-adreno330
TARGET_CPU_ABI := armeabi-v7a
TARGET_CPU_ABI2 := armeabi
TARGET_CPU_VARIANT := krait

TARGET_GLOBAL_CFLAGS += -mfpu=neon -mfloat-abi=softfp
TARGET_GLOBAL_CPPFLAGS += -mfpu=neon -mfloat-abi=softfp

TARGET_NO_BOOTLOADER := false
TARGET_NO_KERNEL := false
TARGET_NO_RADIOIMAGE := true
TARGET_NO_RPC := true

TARGET_BOOTLOADER_BOARD_NAME := $(TARGET_DEVICE)
TARGET_BOOTLOADER_PLATFORM_OVERRIDE := $(TARGET_BOOTLOADER_BOARD_NAME)

# Use signed boot and recovery image
TARGET_BOOTIMG_SIGNED := true

TARGET_USES_AOSP := false

TARGET_ADD_RADIO_FILES := true

# Bionic
TARGET_USE_KRAIT_PLD_SET := true
TARGET_KRAIT_BIONIC_PLDOFFS := 10
TARGET_KRAIT_BIONIC_PLDTHRESH := 10
TARGET_KRAIT_BIONIC_BBTHRESH := 64
TARGET_KRAIT_BIONIC_PLDSIZE := 64

TARGET_USERIMAGES_USE_EXT4 := true
TARGET_HW_DISK_ENCRYPTION := false

# TARGET_COMPILE_WITH_MSM_KERNEL := true
# TARGET_HAS_QC_KERNEL_SOURCE := true
TARGET_KERNEL_APPEND_DTB := false
TARGET_KERNEL_ARCH := arm
TARGET_KERNEL_CROSS_COMPILE_PREFIX := arm-linux-androideabi-
TARGET_KERNEL_SOURCE := kernel/fairphone/msm8974

# Graphics
TARGET_HARDWARE_3D := false
NUM_FRAMEBUFFER_SURFACE_BUFFERS := 3
MAX_EGL_CACHE_KEY_SIZE := 12*1024
MAX_EGL_CACHE_SIZE := 2048*1024

# Include releasetools.py from this location
# For details see docs/src/devices/tech/ota/device_code.jd:1001 or
# https://source.android.com/devices/tech/ota/nonab/device_code#specify-module-location
TARGET_RELEASETOOLS_EXTENSIONS := device/fairphone/FP2

TARGET_LDPRELOAD := libNimsWrap.so # Needed?

BOARD_KERNEL_BASE        := 0x00000000
BOARD_KERNEL_PAGESIZE    := 2048
BOARD_KERNEL_TAGS_OFFSET := 0x01E00000
BOARD_RAMDISK_OFFSET     := 0x02000000

ifneq (,$(filter userdebug eng,$(TARGET_BUILD_VARIANT)))
$(warning Kernel serial console enabled)
BOARD_KERNEL_CMDLINE := earlyprintk=msm_hsl_uart,0x78b0000 console=ttyHSL0,115200,n8 androidboot.hardware=qcom user_debug=31 msm_rtb.filter=0x3b7 ehci-hcd.park=3 androidboot.bootdevice=msm_sdcc.1

#TODO what does this need to be?
TARGET_KERNEL_CONFIG := aosp_userdebug_FP2_defconfig
else
BOARD_KERNEL_CMDLINE := androidboot.hardware=qcom user_debug=31 msm_rtb.filter=0x3b7 ehci-hcd.park=3 androidboot.bootdevice=msm_sdcc.1

#TODO what does this need to be?
TARGET_KERNEL_CONFIG := aosp_FP2_defconfig
endif


BOARD_CACHEIMAGE_FILE_SYSTEM_TYPE := ext4
BOARD_PERSISTIMAGE_FILE_SYSTEM_TYPE := ext4 # Needed?

BOARD_BOOTIMAGE_PARTITION_SIZE := 0x01000000
BOARD_RECOVERYIMAGE_PARTITION_SIZE := 0x01000000
BOARD_SYSTEMIMAGE_PARTITION_SIZE := 2147483648
BOARD_USERDATAIMAGE_PARTITION_SIZE := 27358941675
BOARD_CACHEIMAGE_PARTITION_SIZE := 671088640
BOARD_PERSISTIMAGE_PARTITION_SIZE := 5242880
BOARD_TOMBSTONESIMAGE_PARTITION_SIZE := 73400320
BOARD_FLASH_BLOCK_SIZE := 131072 # (BOARD_KERNEL_PAGESIZE * 64)

BOARD_EGL_CFG := device/fairphone/FP2/egl.cfg

# BOARD_SEPOLICY_DIRS := device/fairphone/FP2/sepolicy ?
BOARD_SEPOLICY_DIRS += device/fairphone/FP2/sepolicy

BOARD_KERNEL_SEPARATED_DT := true

# QCOM hardware
BOARD_USES_QCOM_HARDWARE := true

# MSM related functionality for updater binary in OTA packages
TARGET_RECOVERY_UPDATER_LIBS := librecovery_updater_msm



# TODO Review and add/remove?


# Added to indicate that protobuf-c is supported in this build
PROTOBUF_SUPPORTED := true

# Lights
TARGET_PROVIDES_LIBLIGHT := true

# QCOM hardware
# BOARD_USES_QCOM_HARDWARE := true

# Audio
AUDIO_FEATURE_ENABLED_COMPRESS_VOIP := false
AUDIO_FEATURE_ENABLED_HWDEP_CAL := true
AUDIO_FEATURE_ENABLED_LOW_LATENCY_CAPTURE := true
AUDIO_FEATURE_ENABLED_MULTI_VOICE_SESSIONS := true
AUDIO_FEATURE_ENABLED_NEW_SAMPLE_RATE := true
AUDIO_FEATURE_LOW_LATENCY_PRIMARY := true
BOARD_USES_ALSA_AUDIO := true
USE_CUSTOM_AUDIO_POLICY := 1

# Camera
BOARD_GLOBAL_CFLAGS += -DCAMERA_VENDOR_L_COMPAT
TARGET_HAS_LEGACY_CAMERA_HAL1 := true
TARGET_USE_COMPAT_GRALLOC_ALIGN := true
#USE_DEVICE_SPECIFIC_CAMERA := false
BOARD_QTI_CAMERA_32BIT_ONLY := true

PRODUCT_DEFAULT_PROPERTY_OVERRIDES += \
    camera2.portability.force_api=1

# Graphics
MAX_EGL_CACHE_KEY_SIZE := 12*1024
MAX_EGL_CACHE_SIZE := 2048*1024
NUM_FRAMEBUFFER_SURFACE_BUFFERS := 3
OVERRIDE_RS_DRIVER := libRSDriver_adreno.so
TARGET_USES_ION := true
TARGET_USES_NEW_ION_API := true
USE_OPENGL_RENDERER := true

# Encryption
TARGET_HW_DISK_ENCRYPTION := false

# Bluetooth
BOARD_HAVE_BLUETOOTH := true
BOARD_HAVE_BLUETOOTH_QCOM := true
BLUETOOTH_HCI_USE_MCT := true
BOARD_BLUETOOTH_BDROID_BUILDCFG_INCLUDE_DIR := device/fairphone/FP2/bluetooth
QCOM_BT_USE_SMD_TTY := true
FEATURE_QCRIL_UIM_SAP_SERVER_MODE := true

# ANT+
BOARD_ANT_WIRELESS_DEVICE := "vfs-prerelease"

# Wifi
BOARD_HAS_QCOM_WLAN              := true
BOARD_HAS_QCOM_WLAN_SDK          := true
BOARD_WLAN_DEVICE                := qcwcn
BOARD_WPA_SUPPLICANT_DRIVER      := NL80211
BOARD_WPA_SUPPLICANT_PRIVATE_LIB := lib_driver_cmd_qcwcn
BOARD_HOSTAPD_DRIVER             := NL80211
BOARD_HOSTAPD_PRIVATE_LIB        := lib_driver_cmd_qcwcn
WIFI_DRIVER_FW_PATH_STA          := "sta"
WIFI_DRIVER_FW_PATH_AP           := "ap"
WPA_SUPPLICANT_VERSION           := VER_0_8_X

TARGET_USES_QCOM_WCNSS_QMI := true

# Radio
TARGET_RIL_VARIANT := caf
BOARD_RIL_CLASS := ../../../device/fairphone/FP2/ril/

# GPS
BOARD_VENDOR_QCOM_LOC_PDK_FEATURE_SET := true
USE_DEVICE_SPECIFIC_GPS := true
USE_DEVICE_SPECIFIC_LOC_API := true
TARGET_NO_RPC := true

# SELinux
include device/qcom/sepolicy/sepolicy.mk
BOARD_SEPOLICY_DIRS += \
    $(DEVICE_PATH)/sepolicy

# CM Hardware
BOARD_USES_CYANOGEN_HARDWARE := false
#BOARD_HARDWARE_CLASS += \
#    hardware/cyanogen/cmhw
BACKLIGHT_PATH=/sys/class/leds/lcd-backlight/brightness

# QCOM Power
TARGET_POWERHAL_VARIANT := qcom

# FM
AUDIO_FEATURE_ENABLED_FM_POWER_OPT := true
BOARD_HAVE_QCOM_FM := true
TARGET_FM_LEGACY_PATCHLOADER := true

# Init
TARGET_INIT_VENDOR_LIB := libinit_msm8974
TARGET_RECOVERY_DEVICE_MODULES := libinit_msm8974

# Vold
TARGET_VOLD_VENDOR_LIB := libvold_msm8974

# Malloc
MALLOC_SVELTE := true

WITHOUT_CHECK_API := true
TARGET_DISABLE_CMSDK := true

-include vendor/fairphone/FP2/BoardConfigVendor.mk
